==> trivianpm-1.0.0.tgz: package/index.js <==

let posibilidades = [
{
  question: '¿Quien es este personaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847269357406519316/descarga.jpeg',
  answers: ['Peppa pig',"Winie Pu","Winnie Pooh"],
  answer: 'Ẁinnie Pooh'
},
{
  question: '¿Como se llama este lugar ficticio?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847272197936513094/incognity.png',
  answers: ["Torre de los vengadores",'Torre DC',"Torre Marvel"],
  answer: 'Torre de los vengadores'
},
{
  question: '¿De que serie / pelicula es este lenguaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847273071160459274/abecedario.jpeg',
  answers: ['Star Wars',"Stark Trek","Star Land"],
  answer: 'Stark Trek'
},
{
  question: '¿Como se llama este continente ficticio?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847274252041846784/Kvp_31.jpg',
  answers: ["Ooo","Post apocaliptico","Iii"],
  answer: 'Ooo'
},
{
  question: '¿Como se llama este personaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847274853148655636/41bC-NFUEL._AC_.jpg',
  answers: ["Bmo","Finn","Jake"],
  answer: 'Finn'
},
{
  question: '¿Que pais es este?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276007974371348/pais.png',
  answers: ["Argelia","Brasil","India"],
  answer: 'Argelia'
},
{
  question: '¿Como se llama este alimento?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276357435916298/Argentina.jpg',
  answers: ['Dulce',"Cerebritos","Alfajor"],
  answer: 'Alfajor'
},
{
  question: '¿Cual es el pais de el que proviene este alimento?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276796952051752/otac.jpeg',
  answers: ['Argentina','Chile','Mexico'],
  answer:  'Mexico'
},
{
  question: '¿En que decada se invento el televisor?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847277297110614057/descarga_1.jpeg',
  answers: ["1010","1920","1930"],
  answer: "1920"
},
{
  question: '¿En que siclo se invento la camara fotografica?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847277870686142495/foto.jpg',
  answers: ["1900","1600","1800"],
  answer:"1600"
}]
module.exports = {
  let random = posibilidades[Math.floor(Math.random()*posibilidades.length)]
  getTrivia : async function ( ) {
    return random
  }
}

==> trivianpm-1.3.0.tgz: package/index.js <==

let posibilidades = [
{
  question: '¿Quien es este personaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847269357406519316/descarga.jpeg',
  answers: ['Peppa pig',"Winie Pu","Winnie Pooh"],
  answer: 'Ẁinnie Pooh'
},
{
  question: '¿Como se llama este lugar ficticio?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847272197936513094/incognity.png',
  answers: ["Torre de los vengadores",'Torre DC',"Torre Marvel"],
  answer: 'Torre de los vengadores'
},
{
  question: '¿De que serie / pelicula es este lenguaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847273071160459274/abecedario.jpeg',
  answers: ['Star Wars',"Stark Trek","Star Land"],
  answer: 'Stark Trek'
},
{
  question: '¿Como se llama este continente ficticio?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847274252041846784/Kvp_31.jpg',
  answers: ["Ooo","Post apocaliptico","Iii"],
  answer: 'Ooo'
},
{
  question: '¿Como se llama este personaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847274853148655636/41bC-NFUEL._AC_.jpg',
  answers: ["Bmo","Finn","Jake"],
  answer: 'Finn'
},
{
  question: '¿Que pais es este?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276007974371348/pais.png',
  answers: ["Argelia","Brasil","India"],
  answer: 'Argelia'
},
{
  question: '¿Como se llama este alimento?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276357435916298/Argentina.jpg',
  answers: ['Dulce',"Cerebritos","Alfajor"],
  answer: 'Alfajor'
},
{
  question: '¿Cual es el pais de el que proviene este alimento?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276796952051752/otac.jpeg',
  answers: ['Argentina','Chile','Mexico'],
  answer:  'Mexico'
},
{
  question: '¿En que decada se invento el televisor?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847277297110614057/descarga_1.jpeg',
  answers: ["1010","1920","1930"],
  answer: "1920"
},
{
  question: '¿En que siclo se invento la camara fotografica?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847277870686142495/foto.jpg',
  answers: ["1900","1600","1800"],
  answer:"1600"
}]
module.exports = {
  getTrivia : async function ( ) {
    let randonc = posibilidades[Math.floor(Math.random()*posibilidades.length)]
    return randonc
  }
}
